##################################################
# User-Defined Macros:
# %%define <name> <expansion>
%define Name		php-dbg-server
%define Version		2.10pl3
%define Release		6


Summary: PHP debugger
Name: %{Name}
Version: %{Version}
Release: %{Release}
Copyright: The DBG License, version 1.10
Group: Development/Debuggers
URL: http://dd.cron.ru/dbg/
BuildRequires: php-devel >= 4.2.2-8.0.5
Requires: php
Requires: perl
Obsoletes: php-dbg


##################################################
# The only one and true src
Source0: php-dbg-server-2.10pl3.tar.gz


BuildRoot: %{_tmppath}/%{Name}-%{Version}-%{Release}-root


%description
Php Debugger DBG is a comprehensive software tool that helps you to
debug your php script. It may work with your production or development
WEB server or locally without any other computers.
Generally DBG allows:
    * execute scripts in step-by-step
          o step-in
          o step-out
          o step-over
          o run (continue)
          o pause
    o break (stop)
    * work with breakpoints which
          o support conditions (to be met before breakpoint fires)
          o can be temporary (to implement goto cursor)
          o can be global (not at any given line/file, but simply
            global)
    o can skip certain number of hits
    * work with watch/eval
          o can evaluate any given statement(s) at a time (just
            like eval() in php)
    o can perform it at a given nested call (back-trace location)
      - so you can change or see any values local to function(s)
      where the current function was called from.
    * call-stack/back-trace
* profile scripts. Shows how many microseconds were spent for each
  executed line including min, max, avg values and number of hits. 

This package provides the server portion of the debugging enviroment.
You will need a client capable of communicating with the dbg server
to make full use of the debugging enviroment.
(see http://dd.cron.ru/dbg/installation.php for additional details)


%prep
%setup
##################################################
# phpize is provided by php-devel and copies
# in needed files to allow the code here to be
# intergrated with the installed version of php
#
phpize

##################################################
# need to run aclocal
#
aclocal

%configure \
	--enable-dbg=shared \
        --with-dbg-profiler \
	--with-php-config=%{_bindir}/php-config


%build
CPPFLAGS="-DHAVE_CONFIG_H" make


%install
rm -f modules/*.la
mkdir -p $RPM_BUILD_ROOT/%{_libdir}/php4
cp modules/* $RPM_BUILD_ROOT/usr/lib/php4


%clean
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT


%post
##################################################
# Is there a Dbg section in php.ini already?
# Normally grep's exit status is 0 if matches were
# found, and 1 if no matches were found
#
if grep -q "debugger." %{_sysconfdir}/php.ini  ; then
  exit 0
else
  cat >> %{_sysconfdir}/php.ini << EOF

[Debugger]
debugger.enabled		=	True		; enables dbg extension
debugger.profiler_enabled	=	True		; enables dbg profiler
debugger.JIT_enabled		=	True		; enables JIT sessions
debugger.JIT_port		=	7869		; default port to be used, this should be the same as the port number opened by the dbglistener
debugger.JIT_host		=	clienthost	; either real client IP or a keyword clienthost
debugger.JIT_level		=	3		; JIT activation level
;							  0 - disables JIT
;							  1 - E_CORE,
;							  2 - E_CORE | E_ERROR | E_PARSE | E_COMPILE_ERROR | E_USER_ERROR,
;                 					  3 - E_ALL & ~(E_NOTICE | E_USER_NOTICE),
; 							  4 - E_ALL
EOF
fi

##################################################
# Next we want to add in the "extension=dbg.so"
# directive. As no one uses the dbase.so extn.
# we'll abuse it
#
%{__perl} -pi -e "s|^;extension=dbase.so|extension=dbg.so|" %{_sysconfdir}/php.ini
%{__perl} -pi -e "s|^;extension=dbase.dll|extension=dbg.so|" %{_sysconfdir}/php.ini


%postun
##################################################
# Sort of a blunderbus way of doing it but works
#
grep -v -i "debugger" %{_sysconfdir}/php.ini \
	> %{_sysconfdir}/php.ini.dbg.orig
mv %{_sysconfdir}/php.ini.dbg.orig %{_sysconfdir}/php.ini


##################################################
# Next we want to delete "extension=dbg.so"
# directive. We'll return it to the way it was
#
%{__perl} -pi -e "s|^extension=dbg.so|;extension=dbase.so|" \
	 %{_sysconfdir}/php.ini


%files
%attr(-   ,root,root) %doc AUTHORS COPYING INSTALL LICENSE.RTF VERSION
%attr(0755,root,root) %{_libdir}/php4/*


%changelog

* Wed Sep 3 2002 Philip Copeland <bryce@redhat.com> 2.10pl3-6
- Rebuilt as php dropped ZTS support

* Wed Jun 24 2002 Philip Copeland <bryce@redhat.com> 2.10pl3-5
- Damn,.. forgot to make the spec file use grep -q
  in %post else you get noisy rpm output if the debug
  entries already exist in php.ini

* Tue Jun 23 2002 Philip Copeland <bryce@redhat.com> 2.10pl3-4
- Rebuilt because of possibly incompatible c++/library updates

* Thu Jun 16 2002 Philip Copeland <bryce@redhat.com> 2.10pl3-3
- Changed the defaults slightly

* Sat Jun 16 2002 Philip Copeland <bryce@redhat.com> 2.10pl3-1
- Initial attempt making dbg into an rpm
- This is only the server part. As there is a linux client
  I've had to shift directory names around a bit to keep
  rpm happy 8/ Added a VERSION file so that we all know
  what level the sources are.
